@@ -70,6 +70,13 @@ impl NoteError {
     pub fn set_url(&mut self, url: Url) {
         self.file = Some(url);
     }
+    /// Set a local path for the error
+    #[inline]
+    #[cfg(any(unix, windows, target_os = "redox"))]
+    pub fn set_path(&mut self, url: &std::path::Path) -> Result<()> {
+        self.file = Some(Url::from_file_path(url)?);
+        Ok(())
+    }
     /// Set a new range for the error
     #[inline]
     pub fn set_range(&mut self, start: usize, end: usize) {
